@@ -824,10 +824,8 @@ pluma_file_bookmarks_store_get_uri (PlumaFileBookmarksStore * model,
 				    GtkTreeIter * iter)
 {
 	GObject * obj;
-	GFile * file = NULL;
 	guint flags;
 	gchar * ret = NULL;
-	gboolean isfs;
 
 	g_return_val_if_fail (PLUMA_IS_FILE_BOOKMARKS_STORE (model), NULL);
 	g_return_val_if_fail (iter != NULL, NULL);
@@ -839,26 +837,25 @@ pluma_file_bookmarks_store_get_uri (PlumaFileBookmarksStore * model,
 			    &obj,
 			    -1);
 
-	if (obj == NULL)
-		return NULL;
-
-	isfs = (flags & PLUMA_FILE_BOOKMARKS_STORE_IS_FS);
-
-	if (isfs && (flags & PLUMA_FILE_BOOKMARKS_STORE_IS_MOUNT))
+	if (obj != NULL)
 	{
-		file = g_mount_get_root (G_MOUNT (obj));
-	}
-	else if (!isfs)
-	{
-		file = g_object_ref (obj);
-	}
+		if (flags & PLUMA_FILE_BOOKMARKS_STORE_IS_FS)
+		{
+			if (flags & PLUMA_FILE_BOOKMARKS_STORE_IS_MOUNT)
+			{
+				GFile * file;
 
-	g_object_unref (obj);
+				file = g_mount_get_root (G_MOUNT (obj));
+				ret = g_file_get_uri (file);
+				g_object_unref (file);
+			}
+		}
+		else
+		{
+			ret = g_file_get_uri (G_FILE (obj));
+		}
 
-	if (file)
-	{
-		ret = g_file_get_uri (file);
-		g_object_unref (file);
+		g_object_unref (obj);
 	}
 
 	return ret;
