@@ -22,23 +22,22 @@
 #include <config.h>
 #endif
 
-#include <libpeas/peas-activatable.h>
-
 #include <pluma/pluma-window.h>
+#include <pluma/pluma-window-activatable.h>
 #include <pluma/pluma-debug.h>
 
 #include "pluma-trail-save-plugin.h"
 
-static void peas_activatable_iface_init (PeasActivatableInterface *iface);
+static void pluma_window_activatable_iface_init (PlumaWindowActivatableInterface *iface);
 
 struct _PlumaTrailSavePluginPrivate
 {
-	GtkWidget *window;
+	PlumaWindow *window;
 };
 
 enum {
 	PROP_0,
-	PROP_OBJECT
+	PROP_WINDOW
 };
 
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaTrailSavePlugin,
@@ -46,8 +45,8 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (PlumaTrailSavePlugin,
                                 PEAS_TYPE_EXTENSION_BASE,
                                 0,
                                 G_ADD_PRIVATE_DYNAMIC (PlumaTrailSavePlugin)
-                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
-                                                               peas_activatable_iface_init))
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (PLUMA_TYPE_WINDOW_ACTIVATABLE,
+                                                               pluma_window_activatable_iface_init))
 
 static void
 strip_trailing_spaces (GtkTextBuffer *text_buffer)
@@ -160,7 +159,7 @@ on_tab_removed (PlumaWindow *window,
 }
 
 static void
-pluma_trail_save_plugin_activate (PeasActivatable *activatable)
+pluma_trail_save_plugin_activate (PlumaWindowActivatable *activatable)
 {
 	PlumaTrailSavePlugin *plugin;
 	PlumaWindow *window;
@@ -190,7 +189,7 @@ pluma_trail_save_plugin_activate (PeasActivatable *activatable)
 }
 
 static void
-pluma_trail_save_plugin_deactivate (PeasActivatable *activatable)
+pluma_trail_save_plugin_deactivate (PlumaWindowActivatable *activatable)
 {
 	PlumaTrailSavePlugin *plugin;
 	PlumaWindow *window;
@@ -252,8 +251,8 @@ pluma_trail_save_plugin_set_property (GObject      *object,
 
 	switch (prop_id)
 	{
-		case PROP_OBJECT:
-			plugin->priv->window = GTK_WIDGET (g_value_dup_object (value));
+		case PROP_WINDOW:
+			plugin->priv->window = PLUMA_WINDOW (g_value_dup_object (value));
 			break;
 
 		default:
@@ -272,7 +271,7 @@ pluma_trail_save_plugin_get_property (GObject    *object,
 
 	switch (prop_id)
 	{
-		case PROP_OBJECT:
+		case PROP_WINDOW:
 			g_value_set_object (value, plugin->priv->window);
 			break;
 
@@ -291,7 +290,7 @@ pluma_trail_save_plugin_class_init (PlumaTrailSavePluginClass *klass)
 	object_class->set_property = pluma_trail_save_plugin_set_property;
 	object_class->get_property = pluma_trail_save_plugin_get_property;
 
-	g_object_class_override_property (object_class, PROP_OBJECT, "object");
+	g_object_class_override_property (object_class, PROP_WINDOW, "window");
 }
 
 static void
@@ -301,7 +300,7 @@ pluma_trail_save_plugin_class_finalize (PlumaTrailSavePluginClass *klass)
 }
 
 static void
-peas_activatable_iface_init (PeasActivatableInterface *iface)
+pluma_window_activatable_iface_init (PlumaWindowActivatableInterface *iface)
 {
 	iface->activate = pluma_trail_save_plugin_activate;
 	iface->deactivate = pluma_trail_save_plugin_deactivate;
@@ -313,6 +312,6 @@ peas_register_types (PeasObjectModule *module)
 	pluma_trail_save_plugin_register_type (G_TYPE_MODULE (module));
 
 	peas_object_module_register_extension_type (module,
-	                                            PEAS_TYPE_ACTIVATABLE,
+	                                            PLUMA_TYPE_WINDOW_ACTIVATABLE,
 	                                            PLUMA_TYPE_TRAIL_SAVE_PLUGIN);
 }
