@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,7 +41,6 @@
 #include "pluma-search-dialog.h"
 #include "pluma-history-entry.h"
 #include "pluma-utils.h"
-#include "pluma-marshal.h"
 #include "pluma-dirs.h"
 
 /* Signals */
@@ -158,8 +158,7 @@ pluma_search_dialog_class_init (PlumaSearchDialogClass *klass)
 		  	      G_TYPE_FROM_CLASS (object_class),
 		  	      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		  	      G_STRUCT_OFFSET (PlumaSearchDialogClass, show_replace),
-			      NULL, NULL,
-			      pluma_marshal_BOOLEAN__VOID,
+			      NULL, NULL, NULL,
 			      G_TYPE_BOOLEAN, 0);
 
 	g_object_class_install_property (object_class, PROP_SHOW_REPLACE,
@@ -313,7 +312,6 @@ pluma_search_dialog_init (PlumaSearchDialog *dlg)
 	GtkWidget *content;
 	GtkWidget *error_widget;
 	gboolean ret;
-	gchar *file;
 	gchar *root_objects[] = {
 		"search_dialog_content",
 		NULL
@@ -331,9 +329,7 @@ pluma_search_dialog_init (PlumaSearchDialog *dlg)
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			     2); /* 2 * 5 + 2 = 12 */
 
-	file = pluma_dirs_get_ui_file ("pluma-search-dialog.ui");
-
-	ret = pluma_utils_get_ui_objects (file,
+	ret = pluma_utils_get_ui_objects (PLUMA_DATADIR "/ui/pluma-search-dialog.ui",
 					  root_objects,
 					  &error_widget,
 					  "search_dialog_content", &content,
@@ -347,7 +343,6 @@ pluma_search_dialog_init (PlumaSearchDialog *dlg)
 					  "wrap_around_checkbutton", &dlg->priv->wrap_around_checkbutton,
 					  "parse_escapes_checkbutton", &dlg->priv->parse_escapes_checkbutton,
 					  NULL);
-	g_free (file);
 
 	if (!ret)
 	{
