@@ -310,7 +310,7 @@ get_selected_text (GtkTextBuffer  *doc,
 	if (!gtk_text_buffer_get_selection_bounds (doc, &start, &end))
 	{
 		if (len != NULL)
-			len = 0;
+			*len = 0;
 
 		return FALSE;
 	}
@@ -398,7 +398,7 @@ do_replace (PlumaSearchDialog *dialog,
 		{
 		need_refind = !g_regex_match_simple(unescaped_search_text,
 						    selected_text,
-						    match_case ? 0 : GTK_TEXT_SEARCH_CASE_INSENSITIVE ,
+						    match_case ? 0 : G_REGEX_CASELESS,
 						    0);
 		}
 	}
