@@ -6,6 +6,7 @@
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
  * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi
  * Copyright (C) 2002-2005 Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,6 +104,14 @@ void		_pluma_cmd_edit_paste			(GtkAction   *action,
 							 PlumaWindow *window);
 void		_pluma_cmd_edit_delete			(GtkAction   *action,
 							 PlumaWindow *window);
+void		_pluma_cmd_edit_upper_case		  (GtkAction   *action,
+							 PlumaWindow *window);
+void		_pluma_cmd_edit_lower_case		(GtkAction   *action,
+							 PlumaWindow *window);
+void		_pluma_cmd_edit_invert_case		(GtkAction   *action,
+							 PlumaWindow *window);
+void		_pluma_cmd_edit_title_case		(GtkAction   *action,
+							 PlumaWindow *window);
 void		_pluma_cmd_edit_select_all		(GtkAction   *action,
 							 PlumaWindow *window);
 void		_pluma_cmd_edit_preferences		(GtkAction   *action,
