@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2008 Ignacio Casal Quinteiro
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,18 +37,6 @@ gchar		*pluma_dirs_get_user_plugins_dir	(void);
 
 gchar		*pluma_dirs_get_user_accels_file	(void);
 
-gchar		*pluma_dirs_get_pluma_data_dir		(void);
-
-gchar		*pluma_dirs_get_pluma_locale_dir	(void);
-
-gchar		*pluma_dirs_get_pluma_lib_dir		(void);
-
-gchar		*pluma_dirs_get_pluma_plugins_dir	(void);
-
-gchar		*pluma_dirs_get_pluma_plugins_data_dir	(void);
-
-gchar		*pluma_dirs_get_ui_file			(const gchar *file);
-
 G_END_DECLS
 
 #endif /* __PLUMA_DIRS_H__ */
