@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005-2007 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,16 +45,18 @@
 #include "pluma-file-chooser-dialog.h"
 #include "pluma-encodings-combo-box.h"
 #include "pluma-language-manager.h"
-#include "pluma-prefs-manager-app.h"
 #include "pluma-debug.h"
 #include "pluma-enum-types.h"
 #include "pluma-utils.h"
+#include "pluma-settings.h"
 
 #define ALL_FILES		_("All Files")
 #define ALL_TEXT_FILES		_("All Text Files")
 
 struct _PlumaFileChooserDialogPrivate
 {
+	GSettings *filter_settings;
+
 	GtkWidget *option_menu;
 	GtkWidget *extra_widget;
 
@@ -64,9 +67,22 @@ struct _PlumaFileChooserDialogPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (PlumaFileChooserDialog, pluma_file_chooser_dialog, GTK_TYPE_FILE_CHOOSER_DIALOG)
 
+static void
+pluma_file_chooser_dialog_dispose (GObject *object)
+{
+	PlumaFileChooserDialog *dialog = PLUMA_FILE_CHOOSER_DIALOG (object);
+
+	g_clear_object (&dialog->priv->filter_settings);
+
+	G_OBJECT_CLASS (pluma_file_chooser_dialog_parent_class)->dispose (object);
+}
+
 static void
 pluma_file_chooser_dialog_class_init (PlumaFileChooserDialogClass *klass)
 {
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+	object_class->dispose = pluma_file_chooser_dialog_dispose;
 }
 
 static void
@@ -247,9 +263,6 @@ filter_changed (PlumaFileChooserDialog *dialog,
 {
 	GtkFileFilter *filter;
 
-	if (!pluma_prefs_manager_active_file_filter_can_set ())
-		return;
-
 	filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
 	if (filter != NULL)
 	{
@@ -264,7 +277,9 @@ filter_changed (PlumaFileChooserDialog *dialog,
 
 		pluma_debug_message (DEBUG_COMMANDS, "Active filter: %s (%d)", name, id);
 
-		pluma_prefs_manager_set_active_file_filter (id);
+		g_settings_set_int (dialog->priv->filter_settings,
+				    PLUMA_SETTINGS_ACTIVE_FILE_FILTER, id);
+
 	}
 }
 
@@ -286,7 +301,7 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 
 		while ((languages != NULL) && (*languages != NULL))
 		{
-			gchar **mime_types;
+			gchar **mime_types_srtv;
 			gint i;
 			GtkSourceLanguage *lang;
 
@@ -294,24 +309,24 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 			g_return_val_if_fail (GTK_SOURCE_IS_LANGUAGE (lang), FALSE);
 			++languages;
 
-			mime_types = gtk_source_language_get_mime_types (lang);
-			if (mime_types == NULL)
+			mime_types_srtv = gtk_source_language_get_mime_types (lang);
+			if (mime_types_srtv == NULL)
 				continue;
 
-			for (i = 0; mime_types[i] != NULL; i++)
+			for (i = 0; mime_types_srtv[i] != NULL; i++)
 			{
-				if (!g_content_type_is_a (mime_types[i], "text/plain"))
+				if (!g_content_type_is_a (mime_types_srtv[i], "text/plain"))
 				{
 					pluma_debug_message (DEBUG_COMMANDS,
 							     "Mime-type %s is not related to text/plain",
-							     mime_types[i]);
+							     mime_types_srtv[i]);
 
 					known_mime_types = g_slist_prepend (known_mime_types,
-									    g_strdup (mime_types[i]));
+									    g_strdup (mime_types_srtv[i]));
 				}
 			}
 
-			g_strfreev (mime_types);
+			g_strfreev (mime_types_srtv);
 		}
 
 		/* known_mime_types always has "text/plain" as first item" */
@@ -350,6 +365,8 @@ static void
 pluma_file_chooser_dialog_init (PlumaFileChooserDialog *dialog)
 {
 	dialog->priv = pluma_file_chooser_dialog_get_instance_private (dialog);
+
+	dialog->priv->filter_settings = g_settings_new (PLUMA_SCHEMA_ID);
 }
 
 static GtkWidget *
@@ -387,7 +404,8 @@ pluma_file_chooser_dialog_new_valist (const gchar          *title,
 				PLUMA_ENCODINGS_COMBO_BOX (PLUMA_FILE_CHOOSER_DIALOG (result)->priv->option_menu),
 				encoding);
 
-	active_filter = pluma_prefs_manager_get_active_file_filter ();
+	active_filter = g_settings_get_int (PLUMA_FILE_CHOOSER_DIALOG (result)->priv->filter_settings,
+					    PLUMA_SETTINGS_ACTIVE_FILE_FILTER);
 	pluma_debug_message (DEBUG_COMMANDS, "Active filter: %d", active_filter);
 
 	/* Filters */
