@@ -158,19 +158,11 @@ message_free (Message *message)
 	g_free (message->method);
 	g_free (message->object_path);
 
-	g_list_foreach (message->listeners, (GFunc)listener_free, NULL);
-	g_list_free (message->listeners);
+	g_list_free_full (message->listeners, (GDestroyNotify) listener_free);
 
 	g_free (message);
 }
 
-static void
-message_queue_free (GList *queue)
-{
-	g_list_foreach (queue, (GFunc)g_object_unref, NULL);
-	g_list_free (queue);
-}
-
 static void
 pluma_message_bus_finalize (GObject *object)
 {
@@ -179,7 +171,7 @@ pluma_message_bus_finalize (GObject *object)
 	if (bus->priv->idle_id != 0)
 		g_source_remove (bus->priv->idle_id);
 
-	message_queue_free (bus->priv->message_queue);
+	g_list_free_full (bus->priv->message_queue, g_object_unref);
 
 	g_hash_table_destroy (bus->priv->messages);
 	g_hash_table_destroy (bus->priv->idmap);
@@ -213,8 +205,7 @@ pluma_message_bus_class_init (PlumaMessageBusClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaMessageBusClass, dispatch),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_MESSAGE);
@@ -233,8 +224,7 @@ pluma_message_bus_class_init (PlumaMessageBusClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaMessageBusClass, registered),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_MESSAGE_TYPE);
@@ -253,8 +243,7 @@ pluma_message_bus_class_init (PlumaMessageBusClass *klass)
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PlumaMessageBusClass, unregistered),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__BOXED,
+			      NULL, NULL, NULL,
 			      G_TYPE_NONE,
 			      1,
 			      PLUMA_TYPE_MESSAGE_TYPE);
@@ -432,7 +421,7 @@ idle_dispatch (PlumaMessageBus *bus)
 		dispatch_message (bus, msg);
 	}
 
-	message_queue_free (list);
+	g_list_free_full (list, g_object_unref);
 	return FALSE;
 }
 
