@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2005 - Paolo Maggi
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,13 +45,13 @@ G_BEGIN_DECLS
 static const GtkActionEntry pluma_always_sensitive_menu_entries[] =
 {
 	/* Toplevel */
-	{ "File", NULL, N_("_File") },
-	{ "Edit", NULL, N_("_Edit") },
-	{ "View", NULL, N_("_View") },
-	{ "Search", NULL, N_("_Search") },
-	{ "Tools", NULL, N_("_Tools") },
-	{ "Documents", NULL, N_("_Documents") },
-	{ "Help", NULL, N_("_Help") },
+	{ "File", NULL, N_("_File"), NULL, NULL, NULL },
+	{ "Edit", NULL, N_("_Edit"), NULL, NULL, NULL },
+	{ "View", NULL, N_("_View"), NULL, NULL, NULL },
+	{ "Search", NULL, N_("_Search"), NULL, NULL, NULL },
+	{ "Tools", NULL, N_("_Tools"), NULL, NULL, NULL },
+	{ "Documents", NULL, N_("_Documents"), NULL, NULL, NULL },
+	{ "Help", NULL, N_("_Help"), NULL, NULL, NULL },
 
 	/* File menu */
 	{ "FileNew", "document-new", N_("_New"), "<control>N",
@@ -103,9 +104,18 @@ static const GtkActionEntry pluma_menu_entries[] =
 	  N_("Delete the selected text"), G_CALLBACK (_pluma_cmd_edit_delete) },
 	{ "EditSelectAll", "edit-select-all", N_("Select _All"), "<control>A",
 	  N_("Select the entire document"), G_CALLBACK (_pluma_cmd_edit_select_all) },
+	{ "ChangeCase", NULL, N_("C_hange Case"), NULL, NULL, NULL },
+	{ "UpperCase", NULL, N_("All _Upper Case"), NULL,
+	  N_("Change selected text to upper case"), G_CALLBACK (_pluma_cmd_edit_upper_case) },
+	{ "LowerCase", NULL, N_("All _Lower Case"), NULL,
+	  N_("Change selected text to lower case"), G_CALLBACK (_pluma_cmd_edit_lower_case) },
+	{ "InvertCase", NULL, N_("_Invert Case"), NULL,
+	  N_("Invert the case of selected text"), G_CALLBACK (_pluma_cmd_edit_invert_case) },
+	{ "TitleCase", NULL, N_("_Title Case"), NULL,
+	  N_("Capitalize the first letter of each selected word"), G_CALLBACK (_pluma_cmd_edit_title_case) },
 
 	/* View menu */
-	{ "ViewHighlightMode", NULL, N_("_Highlight Mode") },
+	{ "ViewHighlightMode", NULL, N_("_Highlight Mode"), NULL, NULL, NULL },
 
 	/* Search menu */
 	{ "SearchFind", "edit-find", N_("_Find..."), "<control>F",
