@@ -518,10 +518,9 @@ pluma_warning (GtkWindow *parent, const gchar *format, ...)
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
-	g_signal_connect (G_OBJECT (dialog),
-			  "response",
-			  G_CALLBACK (gtk_widget_destroy),
-			  NULL);
+	g_signal_connect (dialog, "response",
+	                  G_CALLBACK (gtk_widget_destroy),
+	                  NULL);
 
 	gtk_widget_show (dialog);
 }
