@@ -97,7 +97,7 @@ struct _PlumaViewPrivate
     GtkWidget   *search_entry;
 
     guint        typeselect_flush_timeout;
-    guint        search_entry_changed_id;
+    gulong       search_entry_changed_id;
 
     gboolean     disable_popdown;
 
@@ -1226,12 +1226,17 @@ hide_search_window (PlumaView *view, gboolean cancel)
     if (view->priv->disable_popdown)
         return;
 
+#if GLIB_CHECK_VERSION(2,62,0)
+    g_clear_signal_handler (&view->priv->search_entry_changed_id,
+                            view->priv->search_entry);
+#else
     if (view->priv->search_entry_changed_id != 0)
     {
         g_signal_handler_disconnect (view->priv->search_entry,
                                      view->priv->search_entry_changed_id);
         view->priv->search_entry_changed_id = 0;
     }
+#endif
 
     if (view->priv->typeselect_flush_timeout != 0)
     {
@@ -1518,7 +1523,7 @@ search_entry_populate_popup (GtkEntry  *entry,
 
     /* create "Wrap Around" menu item. */
     menu_item = gtk_check_menu_item_new_with_mnemonic (_("_Wrap Around"));
-    g_signal_connect (G_OBJECT (menu_item), "toggled",
+    g_signal_connect (menu_item, "toggled",
                       G_CALLBACK (wrap_around_menu_item_toggled),
                       view);
     gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
@@ -1528,7 +1533,7 @@ search_entry_populate_popup (GtkEntry  *entry,
 
     /* create "Match Entire Word Only" menu item. */
     menu_item = gtk_check_menu_item_new_with_mnemonic (_("Match _Entire Word Only"));
-    g_signal_connect (G_OBJECT (menu_item), "toggled",
+    g_signal_connect (menu_item, "toggled",
                       G_CALLBACK (match_entire_word_menu_item_toggled),
                       view);
     gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
@@ -1538,7 +1543,7 @@ search_entry_populate_popup (GtkEntry  *entry,
 
     /* create "Match Case" menu item. */
     menu_item = gtk_check_menu_item_new_with_mnemonic (_("_Match Case"));
-    g_signal_connect (G_OBJECT (menu_item), "toggled",
+    g_signal_connect (menu_item, "toggled",
                       G_CALLBACK (match_case_menu_item_toggled),
                       view);
     gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
@@ -1548,7 +1553,7 @@ search_entry_populate_popup (GtkEntry  *entry,
 
     /* create "Parse escapes" menu item. */
     menu_item = gtk_check_menu_item_new_with_mnemonic (_("_Parse escape sequences (e.g. \n)"));
-    g_signal_connect (G_OBJECT (menu_item), "toggled",
+    g_signal_connect (menu_item, "toggled",
                       G_CALLBACK (parse_escapes_menu_item_toggled),
                       view);
     gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
@@ -1857,7 +1862,7 @@ get_selected_text (GtkTextBuffer *doc, gchar **selected_text, gint *len)
     if (!gtk_text_buffer_get_selection_bounds (doc, &start, &end))
     {
         if (len != NULL)
-            len = 0;
+            *len = 0;
 
         return FALSE;
     }
