@@ -3,6 +3,7 @@
  * This file is part of pluma
  *
  * Copyright (C) 2010 - Jesse van den Kieboom
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * pluma is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +21,7 @@
  * Boston, MA  02110-1301  USA
  */
 
-#include "pluma-gio-document-loader.h"
-#include "pluma-prefs-manager-app.h"
+#include "pluma-document-loader.h"
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <glib.h>
@@ -42,7 +42,6 @@
 #define UNOWNED_LOCAL_DIRECTORY "/tmp/pluma-document-saver-unowned"
 #define UNOWNED_LOCAL_URI "/tmp/pluma-document-saver-unowned/pluma-document-saver-test.txt"
 
-#define UNOWNED_REMOTE_DIRECTORY "sftp://localhost/tmp/pluma-document-saver-unowned"
 #define UNOWNED_REMOTE_URI "sftp://localhost/tmp/pluma-document-saver-unowned/pluma-document-saver-test.txt"
 
 #define UNOWNED_GROUP_LOCAL_URI "/tmp/pluma-document-saver-unowned-group.txt"
@@ -689,8 +688,6 @@ int main (int   argc,
 
 	g_test_init (&argc, &argv, NULL);
 
-	pluma_prefs_manager_app_init ();
-
 	g_printf ("\n***\n");
 	have_unowned = check_unowned_directory ();
 	have_unowned_group = check_unowned_group ();
